web2ldap as generic LDAP client only displays the dynamically retrieved content of 3rd-party LDAP directories. I am not responsible for the data displayed through web2ldap demo in any way.

Æ-DIR demo
  web2ldap used as admin UI for Æ-DIR with write access for different admin roles (see Æ-DIR | User Guide -- web2ldap).
Schema browser
  Directly jump into the schema browser:
  - Æ-DIR
  - /oid?ldap://ipa.demo1.freeipa.org/dc=demo1,dc=freeipa,dc=org"> FreeIPA (389-DS)
More public LDAP servers...
  More LDAP public servers to access through the ">demo web2ldap service.